@@ -15,13 +15,16 @@ class Map(Module):
         )
 
         self.function = function
+        self.kwargs = kwargs
 
     def run(self, instance: Instance, **kwargs):
         fn = self._load_function(self.function)
         if fn is None:
             raise RuntimeError(f"Unable to load function {self.function}")
 
-        result = fn(instance=instance)
+        arguments = {**self.kwargs, **kwargs}
+
+        result = fn(instance=instance, **arguments)
 
         if not isinstance(result, dict):
             raise RuntimeError("The result of the map operation must be a dictionary")
