@@ -54,6 +54,27 @@ class Module(object):
             raise InternalError(f"Unable to load function {function_name}")
 
 
+class Dependency(Module):
+    def __init__(
+        self,
+        function: str = None,
+        **kwargs,
+    ):
+        super().__init__(**kwargs)
+
+        self.function = function
+        self.kwargs = kwargs
+
+    def get(self, **kwargs):
+        fn = self._load_function(self.function)
+        if fn is None:
+            raise RuntimeError(f"Unable to load function {self.function}")
+
+        arguments = {**self.kwargs, **kwargs}
+
+        return fn(**arguments)
+
+
 class Connection(Module):
     def __init__(
         self,
